package cn.zhangdeman;

import java.util.HashMap;
import java.util.Map;

// 基于hashmap实现的内存缓存
// 因为就是服务启动时初始化一次, 无需考虑多线程并发安全问题
public class HashMapCache {
    // 单例: 饿汉模式
    private static final HashMapCache hashMapCache = new HashMapCache();
    private final Map<Object, String> cache = new HashMap<>();
    //将构造器设置为private禁止通过new进行实例化
    private HashMapCache() {

    }
    public static HashMapCache getHashMapCache() {
        return hashMapCache;
    }
    // 读取
    public String getCodeMessage(Object code) {
        if (!cache.containsKey(code)) {
            // 不包含指定code
            return code.toString();
        }
        return cache.get(code);
    }

    // 添加
    public void put(Object code, String message) {
        cache.put(code, message);
    }
}
